@@ -66,14 +66,14 @@ LearnerClassifMultinom = R6Class("LearnerClassifMultinom",
 
       if (self$predict_type == "response") {
         response = mlr3misc::invoke(stats::predict, self$model, newdata = newdata, type = "class")
-        mlr3::PredictionClassif$new(task = task, response = drop(response))
+        list(response = drop(response))
       } else {
         prob = mlr3misc::invoke(stats::predict, self$model, newdata = newdata, type = "probs")
         if (length(levs) == 2L) {
           prob = matrix(c(1 - prob, prob), ncol = 2L, byrow = FALSE)
           colnames(prob) = levs
         }
-        mlr3::PredictionClassif$new(task = task, prob = prob)
+        list(prob = prob)
       }
     }
   )
