@@ -1,7 +1,7 @@
 context("classif.log_reg")
 
 test_that("autotest", {
-  learner = LearnerClassifLogReg$new()
+  learner = mlr3::lrn("classif.log_reg")
   expect_learner(learner)
   result = run_autotest(learner)
   expect_true(result, info = result$error)
